@@ -63,10 +63,9 @@ def main():
     argspec['environment'] = dict(required=False, type='str', default='AzurePublicCloud')
     argspec['resource'] = dict(required=False, type='str', default='https://management.azure.com')
     argspec['config_file'] = dict(required=False, type='str', default=None)
-    supports_check_mode = True
     required_together = [['client_id', 'client_secret', 'tenant_id']]
 
-    module = hashivault_init(argspec, supports_check_mode, required_together)
+    module = hashivault_init(argspec, supports_check_mode=True, required_together=required_together)
     result = hashivault_azure_auth_config(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -107,7 +106,7 @@ def hashivault_azure_auth_config(module):
         enabled_methods = result.get('data', result)
         if (mount_point + "/") not in enabled_methods:
             return {'failed': True, 'msg': 'auth mount is not enabled', 'rc': 1}
-    except:
+    except Exception:
         if module.check_mode:
             changed = True
         else:
@@ -115,7 +114,7 @@ def hashivault_azure_auth_config(module):
 
     try:
         current_state = client.auth.azure.read_config()
-    except:
+    except Exception:
         changed = True
 
     # check if current config matches desired config values, if they dont match, set changed true
