@@ -4,7 +4,6 @@ from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
 from ansible.module_utils.hashivault import hashiwrapper
 import json
-from ast import literal_eval
 
 ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
 DOCUMENTATION = '''
@@ -94,9 +93,7 @@ def main():
     argspec['bound_scale_sets'] = dict(required=False, type='list', default=[])
     argspec['num_uses'] = dict(required=False, type='int', default=0)
 
-    supports_check_mode = True
-
-    module = hashivault_init(argspec, supports_check_mode)
+    module = hashivault_init(argspec, supports_check_mode=True)
     result = hashivault_azure_auth_role(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -144,7 +141,7 @@ def hashivault_azure_auth_role(module):
         if name in existing_roles['keys']:
             # this role exists
             exists = True
-    except:
+    except Exception:
         # no roles exist yet
         pass
 
