@@ -4,7 +4,6 @@ from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
 from ansible.module_utils.hashivault import hashiwrapper
 import json
-from ast import literal_eval
 
 ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
 DOCUMENTATION = '''
@@ -71,9 +70,7 @@ def main():
     argspec['role_file'] = dict(required=False, type='str')
     argspec['state'] = dict(required=False, type='str', default='present', choices=['present', 'absent'])
 
-    supports_check_mode = True
-
-    module = hashivault_init(argspec, supports_check_mode)
+    module = hashivault_init(argspec, supports_check_mode=True)
     result = hashivault_k8s_auth_role(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -109,7 +106,7 @@ def hashivault_k8s_auth_role(module):
         backends = result.get('data', result)
         if (mount_point + "/") not in backends:
             return {'failed': True, 'msg': 'auth method is not enabled', 'rc': 1}
-    except:
+    except Exception:
         if module.check_mode:
             changed = True
         else:
@@ -121,7 +118,7 @@ def hashivault_k8s_auth_role(module):
         if name in existing_roles['keys']:
             # this role exists
             exists = True
-    except:
+    except Exception:
         # no roles exist yet
         pass
 
