@@ -82,9 +82,8 @@ def main():
     argspec['oidc_client_id'] = dict(required=False, type='str')
     argspec['oidc_client_secret'] = dict(required=False, type='str')
     argspec['default_role'] = dict(required=False, type='str')
-    supports_check_mode = True
     required_one_of = [['oidc_discovery_url', 'jwks_url']]
-    module = hashivault_init(argspec, supports_check_mode, required_one_of=required_one_of)
+    module = hashivault_init(argspec, supports_check_mode=True, required_one_of=required_one_of)
     result = hashivault_oidc_auth_method_config(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -130,7 +129,7 @@ def hashivault_oidc_auth_method_config(module):
         backends = result.get('data', result)
         if (mount_point + "/") not in backends:
             return {'failed': True, 'msg': 'auth mount is not enabled', 'rc': 1}
-    except:
+    except Exception:
         if module.check_mode:
             changed = True
         else:
@@ -143,7 +142,7 @@ def hashivault_oidc_auth_method_config(module):
             changed = True
         elif current_state.status_code == 200:
             exists = True
-    except:
+    except Exception:
         changed = True
 
     # check if current config matches desired config values, if they dont match, set changed true
@@ -161,7 +160,7 @@ def hashivault_oidc_auth_method_config(module):
                                       json=desired_state)
         try:
             config_status.raise_for_status()
-        except:
+        except Exception:
             return {'failed': True, 'msg': config_status.text, 'rc': 1}
     return {'changed': changed}
 
