@@ -3,7 +3,6 @@ from ansible.module_utils.hashivault import hashivault_argspec
 from ansible.module_utils.hashivault import hashivault_auth_client
 from ansible.module_utils.hashivault import hashivault_init
 from ansible.module_utils.hashivault import hashiwrapper
-import json
 import requests
 
 ANSIBLE_METADATA = {'status': ['stableinterface'], 'supported_by': 'community', 'version': '1.1'}
@@ -139,9 +138,7 @@ def main():
     argspec['expiration_leeway'] = dict(required=False, type='int', default=0)
     argspec['not_before_leeway'] = dict(required=False, type='int', default=0)
 
-    supports_check_mode = False
-
-    module = hashivault_init(argspec, supports_check_mode)
+    module = hashivault_init(argspec)
     result = hashivault_oidc_auth_role(module)
     if result.get('failed'):
         module.fail_json(**result)
@@ -196,7 +193,7 @@ def hashivault_oidc_auth_role(module):
         backends = result.get('data', result)
         if (mount_point + "/") not in backends:
             return {'failed': True, 'msg': 'auth method is not enabled', 'rc': 1}
-    except:
+    except Exception:
         if module.check_mode:
             changed = True
         else:
@@ -214,7 +211,7 @@ def hashivault_oidc_auth_role(module):
         current_state = s.get(url + '/v1/auth/' + mount_point + '/role/' + name, verify=verify, headers=headers)
         if current_state.status_code == 200:
             exists = True
-    except:
+    except Exception:
         changed = True
 
     if not exists and state == 'present':
